@@ -1,8 +1,8 @@
-from ._julia_project import project
+__version__ = "0.1.10"
+
+from .julia_project import project
 
 # QuantumOps = project.simple_import("QuantumOps")
 # from julia import QuantumOps, QiskitQuantumInfo, ElectronicStructure
 # from .pauli_operators import jlPauli, jlSparsePauliOp, PauliSum_to_SparsePauliOp
 # from .electronic_structure import Geometry, jordan_wigner, fermionic_hamiltonian
-
-from ._version import __version__
