@@ -1,17 +1,15 @@
 import os
-from ._julia_project import project
+
+from qiskit.quantum_info import Pauli, SparsePauliOp, PauliList
+from .julia_project import project
 project.ensure_init()
 
 Main = project.simple_import("Main")
 QuantumOps = project.simple_import("QuantumOps")
 QiskitQuantumInfo = project.simple_import("QiskitQuantumInfo")
 
-# import julia
-# from julia import QuantumOps
-# from julia import QiskitQuantumInfo
-# from julia import Main
-
-from qiskit.quantum_info import Pauli, SparsePauliOp, PauliList
+if project._calljulia_name == 'juliacall':
+    Main.include(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'juliacall_util.jl'))
 
 
 def jlPauli(data):
@@ -32,7 +30,7 @@ def jlPauliList(pauli_list):
 
 def jlSparsePauliOp(sp):
     pl = PauliList.from_symplectic(sp.pauli_list.z, sp.pauli_list.x)
-    return SparsePauliOp(pl, sp.coeffs)
+    return SparsePauliOp(pl, Main.map(Main.float, sp.coeffs))
 
 
 def PauliSum_to_SparsePauliOp(ps):
